@@ -1,8 +1,8 @@
-from hive.core import HivePubSub
+from hive.core import HiveBytePubSub
 import redis
 
 
-class HiveRedis(HivePubSub):
+class HiveRedis(HiveBytePubSub):
 
     def __init__(self, host="localhost", port=6379, db=0):
         self.client = redis.Redis(host=host, port=port, db=db)
@@ -23,5 +23,5 @@ class HiveRedis(HivePubSub):
             msg = self.sub.get_message()
             if msg and msg["type"] == "message":
                 for cb in self.subscriptions[msg["channel"].decode("utf-8")]:
-                    cb(msg["data"])  # adjusting for hive working in bytes
+                    cb(msg["data"])
 
