@@ -3,7 +3,7 @@ import uuid
 
 import stomp
 
-from hive.core import HivePubSub
+from hive.core import HiveBytePubSub
 
 class Listener(stomp.ConnectionListener):
 
@@ -21,7 +21,7 @@ class Listener(stomp.ConnectionListener):
 
 
 
-class HiveStomp(HivePubSub):
+class HiveStomp(HiveBytePubSub):
 
     def __init__(self):
         self.client = stomp.Connection()
